#
# spec file for package python-enaml
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-enaml
Version:        0.9.8
Release:        1.97
Summary:        Declarative UI framework for Python
License:        BSD-3-Clause and LGPL-2.1
Group:          Development/Libraries/Python
# Source code is under BSD but images are under different licenses
# and details are inside image_LICENSE.txt
Url:            https://github.com/enthought/enaml
Source:         https://pypi.python.org/packages/source/e/enaml/enaml-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-casuarius
BuildRequires:  python-devel >= 2.6
BuildRequires:  python-ply
BuildRequires:  python-setuptools
BuildRequires:  python-traits
BuildRequires:  python-wxWidgets
Requires:       python-casuarius
Requires:       python-ply
Requires:       python-traits
Requires:       python-wxWidgets
%if 0%{?suse_version} <= 1110
%{!?python_sitearch:  %global python_sitearch  %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif
%if 0%{?suse_version} > 1210
BuildRequires:  python-pyside
Requires:       python-pyside
%endif

%description
Enaml is a framework for writing declarative user interfaces in Python.
It provides a Yaml-ish/Pythonic syntax language for declaring a ui
that binds and reacts to changes in the user's models. Code can freely 
call back and forth between Python and Enaml.

Part of the Enthought Tool Suite (ETS).

%prep
%setup -q -n enaml-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes -s %{buildroot}

%files
%defattr(-,root,root,-)
%doc COPYING.txt  README.rst licenses/byteplay.txt releasenotes.rst
%doc examples/
%{_bindir}/enaml-run
%{python_sitearch}/enaml/
%{python_sitearch}/enaml-%{version}-py*.egg-info

%changelog
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 0.9.8
  - Add drag and drop support. 56a2127e714c_
  - Remove the Wx backend and free the people from their misery. bab233ff9782_
- Update to 0.9.7
  - Add an IPythonConsole widget.
  - Add support for widgets in tool bars and menus.
  - Add a ToolButton widget.
  - Removed the 'focus_policy' attribute.
  - Removed the 'show_focus_rect' attribute.
  - Fix bugs #122, #123, #124, #131, #145
- Update to 0.9.6
  - Add a declarative function syntax to the grammar.
  - Add a comprehensive focus API. 1090b3f35a9c_
- Update to 0.9.5
  - Allow pressing escape while dragging a floating dock window. e732d2bb3c6c_
  - Fix line ending issues in live editor on old versions of OSX (thanks to JF). 0a54944728ae_
- Update to 0.9.4
  - Allow enamldef objects to be properly pickled. db99d02fa377_
- Update to 0.9.3
  - Return the value of the command handler from CorePlugin.invoke_command. 5322bd1d2a67_
  - Automatically request relayout when widget visibility changes. 5d24f8ab13cb_
  - Add knobs for controlling Form row and column spacing. cdb747d8d1fa_
  - Add VGroup and HGroup convenience layout factories. aed5ddd623d1_
  - Add a 'factory' layout helper. 41480f2694d2_
- Update to 0.9.2
  - Update the layout (if needed) when changing fonts.
  - Minor code cleanup and documentation updates.
- Update to 0.9.1
  - Add the workbench plugin framework. 2ab09c6782b4_
  - Fix idiosyncrasies in layout. 5a9f529671dd_
  - Add a VTKCanvas control. b04262195c27_
  - Add ability to veto a window close. bbd9aa1be9f2_
  - Fix issues #64 #119 #120 #128 #129
- Update to 0.9.0
  - Fix issue #78. f0d1fc7da0d7_
  - Update the layout engine to use the Kiwi solver. d41729049f63_
- Update to 0.8.9
  - Add ability to query window minimized/maximized state. 713feb85952a_
  - Implement 'always_on_top' window flag. 3ac3e6955579_
  - A handful of bug fixes.
- Update to 0.8.8
  - Add a task dialog mini-framework and a MessageBox stlib component. 5583808f293a_
- Update to 0.8.7
  - Add an alerting api for dock items in a dock area. ba766d773090_
- Update to 0.8.6
  - Add 'limit_width' and 'limit_height' virtual constraints. 8722be90844e_
- Update to 0.8.5
  - Add support for style sheets to the DockArea. 5e38c591ad55_
- Update to 0.8.4
  - Add a size hint mode switch to Notebook and Stack. 330c7a337c32d_
- Update to 0.8.3
  - Add support for style sheets. 77e2a0afbd56_
  - Fix a bug with a null widget and the notebook selected tab. 64cfe8789838_
- Update to 0.8.2
  - Add a DynamicTemplate declarative object. ede76a778a86_
  - Add 'window' mode to PopupView. f37263fd7b7d_
  - Add 'selected_tab' attribute to the Notebook. 45ca092e7222_
  - Overhaul of the docs and doc build system.
  - Various bug fixes and performance improvements.
- Update to 0.8.1
  - Update the PopupView to automatically reposition on-screen. 3225683f9411_
  - Minor bug fixes.
  - Added an ImageView example.
- Update to 0.8.0
  - Added templates to the language.
  - Added aliases to the language.
  - Removed the compatibility code scheduled for removal.
  - Added a completely new declarative expression engine.
- Update to 0.7.20
  - Bugfix area layout traversal. 308164fd5134_
  - Allow alpha hex colors. d9605cc55bb5_
  - Add a declarative Timer object. 13259258e6fd_
  - Added a Scintilla widget.
  - Added the applib sub-package.
  - Added live editor components to the applib.
  - Added an 'auto_sync' submit trigger to Field. 1926cde5e64b_
- Update to 0.7.19
  - Added dock layout ops for extending/retracting from dock bars. 00ee34a102f_
  - Added methods for manipulating window geometry. bebba0a82fa_
- Update to 0.7.18
  - Production release of dock area toolbars.
  - Updates to dock layout specification with compatibility env setting.
  - Resizable slide-out dock bar items.
  - Pin buttons on dock items.
  - Improved procedural dock layout modification api.
  - Added a base Frame class which supplies borders for subclasses. d1316f40248_
  - Fixed container ref-cycle issue on widget destruction. 03a5e53038f_
- Update to 0.7.17
  - Added easier to use operator hooks. 2aaf3c96fc8_
  - Added support for PySide. 0d18a21754e_
  - Add cursor anchor mode to PopupView. 74ddd47197e_
  - Initial feedback release of dock area toolbars.
- Update to 0.7.16
  - Add a more useful file dialog as FileDialogEx. 390868cccb_
  - Add a color selection dialog as ColorDialog. d722a876e9_
  - Persist the linked state of floating dock items in a saved layout. adc9dec8db_
  - Add a right click event to the dock item title bar. 812e97aebcf_
  - Make the dock item title user editable. 54b68881529_
  - Make the visibility of the dock item title bar configurable. 54b68881529_
  - Toggle the maximized state of a dock item on title bar double click. 4ffe9d6b68e_
  - Add a RawWidget widget to easily embed external widgets into Enaml. e9d25a29e77_
- Update to 0.7.15
  - Fix a bug in parsing elif blocks. e25363b005_
- Update to 0.7.14
  - Make the translucent background of PopupView configurable. 0731314117_
  - Add a 'live_drag' flag to the DockArea. 0cd6889b2c_
- Update to 0.7.13
  - Feature improvements and fixes to snappable dock frames. 693a6f363a_
  - Add a 'link_activated' event to the Label widget. 269b386639_
- Update to 0.7.12
  - Make floating dock windows snappable and linkable. de3ced381e_
- Update to 0.7.11
  - Claw back the direct exposure of the Qt stylesheets. 947760ebcd_
- Update to 0.7.10
  - Expose the Qt stylesheet directly for the dock area. 5877335bcf_
  - Add the ability to style the various dock area buttons. 5877335bcf_
- Update to 0.7.9
  - Make the close button on dock items configurable. d839fb0c2b_
  - Expose a public api for manipulating the dock layout. e269adbdb2_
  - Expose user configurable dock area styles. 4c05d5953f_
- Update to 0.7.8
  - Add support for maximizing a docked item within a DockArea. a051862ce5_
  - Update the popup view to use a 45 degree angled arrow. f3edc88fe1_
  - Miscellaneous updates and bug fixes to the DockArea.
- Update to 0.7.7
  - Add support for floating "dock rafts" in the DockArea. 402330dcaf_
  - Add a PopupView widget to support transparent popups and growl-style notifications. a5117121bf_
- Update to 0.7.6
  - Add an advanced DockArea widget. 3ed122b110_
  - Add popup() functionality to the Menu widget. 5363a56f33_
- Update to 0.7.5
  - Fix a bug in the Wx main window implementation. 39f6baee49_
- Update to 0.7.4
  - Add border support for Container on the Qt backend. 505662d5f1_
  - Workaround a logic bug in Wx's handling of modal windows. 56a1e00112_
  - Workaround a Wx segfault during window destruction. a8525788c9_
- Update to 0.7.3
  - Added support for adding/removing models in a ViewTable. 5bc1809340_
  - Added an ObjectCombo control which is a more flexible combo box. 51f3a3c6d3_
  - Emit useful error messages when a backend does not implement a control. b264b3b927_
- Update to 0.7.2
  - Added first real cut at a model-viewer grid-based control. de0d8e35ae_
  - Fix a bug in size hinting during complex relayouts. 963cee88d0_
  - Added hooks for proxy-specific customization. 3e045dfb18_
- Update to 0.7.1
  - Updated compiler infrastructure to produce more extensible parse trees.
  - Various bug fixes.
- Update to 0.7.0
  - First release under new nucleic org.
  - Rewrite of entire framework to sit on top of Atom instead of Traits.
  - Vastly improved backend architecture.
  - Improved compile-time operator binding.
- Update to 0.6.8
  - Added ability to change the Z order of a window and a flag to make it stay on top. d6f618101f_
  - Added a multiline text entry widget. dde4bd3409_
  - Bugfix when ImageView is used in a ScrollArea. 67133d3fec_
- Update to 0.6.7
  - Added a `root_object()` method on the `Object` class which returns the root of the object tree. d9b4830963_
  - Properly handle window modality on the Qt backend. 28f2433814_
  - Add a `destroy_on_close` flag to the `Window` class. 2a63e8cefd_
  - Prevent Wx from destroying top-level windows by default. 8e298e768e_
  - Add support for adding windows to a session at run-time. c090c0fad6_
  - Fix the lifetime bug with the `FileDialog`. 8e354de858_
- Update to 0.6.6
  - Fix the broken unittests and make them Python 2.6 safe. 2c1d7f01d_
- Update to 0.6.5
  - Add a stretch factor to the Splitter widget. c2272cf1ef_
  - Fix bugs in the Wx splitter implementation. dfa542ba3d_
- Update to 0.6.4
  - Add support for icons on notebook pages on the Qt backend. b6426b7ae9_
  - Add support for popup menus in the Wx backend (Qt is already supported). 153f3124b2_
  - Add simpler way of building the optional C++ extensions. 4eebd59ae5_
  - Update enaml-run to play nice with ETS_TOOLKIT. f864975a87_
- Update to 0.6.3
  - Fix critical bug related to traits Disallow and the `attr` keyword. 25755e2bbd_
- Update to 0.6.2
  - Fix critical bug for broken dynamic scoping. a788869ab0_
- Update to 0.6.1
  - Fix critical bug in compiler and expression objects. dfb6f648a1_
- Update to 0.6.0
  - Add Icon and Image support using a lazy loading resource sub-framework. 77d5ca3b01_
  - Add a traitsui support via the TraitsItem widget (care of Steven Silvester). 9cb9126da1_
  - Add matplotlib support via the MPLCanvas widget (care of Steven Silvester). eaa6294566_
  - Updated Session api which is more intuitive and easier to use.
  - Updated Object api which is more intuitive and easier to use.
  - Object lifecycle reflected in a `state` attribute.
  - Huge reduction in memory usage when creating large numbers of objects.
  - Huge reduction in time to create large numbers of objects.
  - New widget registry make it easier to register custom widgets. cc791a52d7_
  - Better and faster code analysis via code tracers. 4eceb09f70_
  - Fix a parser bug related to relative imports. 3e43e73e90_
  - Various other tweaks, bugfixes, and api cleanup.
- Update to 0.5.1
  - Fix a method naming bug in QSingleWidgetLayout. 7a4c9de7e6_
  - Fix a test height computation bug in QFlowLayout. a962d2ae78_
  - Invalidate the QFlowLayout on layout request. 1e91a54245_
  - Dispatch child events immediately when possible. e869f7124f_
  - Destroy child widgets after the children change event is emitted. c695ae35ee_
  - Add a preliminary WebView widget. 27faa381dc_
- Update to 0.5.0
  - Merge the feature-async branch into mainline. f86dad8f6e_
  - First release with release notes. 8dbed4b9cd_
- Update source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Tue May 22 2012 toddrme2178@gmail.com
- Initial spec file
